[FFmpeg-soc] [soc]: r3059 - aac/aac.c

superdump subversion at mplayerhq.hu
Thu Aug 7 13:38:38 CEST 2008


Author: superdump
Date: Thu Aug  7 13:38:38 2008
New Revision: 3059

Log:
Rename extension_payload() as decode_extension_payload and sync comment


Modified:
   aac/aac.c

Modified: aac/aac.c
==============================================================================
--- aac/aac.c	(original)
+++ aac/aac.c	Thu Aug  7 13:38:38 2008
@@ -1325,11 +1325,11 @@ static int decode_dynamic_range(DynamicR
 }
 
 /**
  * Parse extension data (incomplete); reference: table 4.51.
  *
  * @param   cnt length of ID_FIL syntactic element in bytes
  */
-static int extension_payload(AACContext * ac, GetBitContext * gb, int cnt) {
+static int decode_extension_payload(AACContext * ac, GetBitContext * gb, int cnt) {
     int crc_flag = 0;
     int res = cnt;
     switch (get_bits(gb, 4)) { // extension type
@@ -1918,7 +1918,7 @@ static int aac_decode_frame(AVCodecConte
             if (tag == 15)
                 tag += get_bits(&gb, 8) - 1;
             while (tag > 0)
-                tag -= extension_payload(ac, &gb, tag);
+                tag -= decode_extension_payload(ac, &gb, tag);
             err = 0; /* FIXME */
             break;
 
@@ -1325,11 +1325,11 @@ static int decode_dynamic_range(DynamicR
 
 /**
- * Parse extension data (incomplete); reference: table 4.51.
+ * Decode extension data (incomplete); reference: table 4.51.
  *
  * @param   cnt length of ID_FIL syntactic element in bytes



More information about the FFmpeg-soc mailing list